use std::{fs, path::PathBuf};


#[derive(Debug, PartialEq, Clone)]
pub struct WordBank {
    pub words: Vec<String>
}

impl WordBank {
    pub fn load() -> Option<Self> {
        let fp = PathBuf::from("words.txt");
        if let Ok(content) = fs::read_to_string(fp) {
            let parts: Vec<&str> = content.split("\n").collect();
            let mut wb: WordBank = WordBank { words: Vec::with_capacity(parts.len()) };
            for line in parts {
                if line.to_string().replace("\r", "").is_empty() {
                    continue;
                }
                wb.words.push(line.to_string().replace("\r", ""));
            }
            Some(wb)
        } else {
            None
        }
    }
    pub fn get_difficulty(&self, line: usize) -> usize {
        if let Some(word) = self.words.get(line) {
            let mut diff = word.len();
            if word.contains(|c: char| {
                // Make Uppercase, numbers, and spaces worth double
                c.is_uppercase() | c.is_numeric() | c.is_whitespace()
            }) {
                diff += 1;
            }
            if word.contains(|c: char| {
                // Make punctuation triple
                c.is_ascii_punctuation()
            }) {
                diff += 2;
            }
            diff
        } else {
            0
        }        
    }
}